@@ -84,7 +84,7 @@ class NWSAPy:
         :rtype: request.Response
         """
         self._check_user_agent()
-        response = request_from_api(url, self._user_agent_to_d,                 as_response_object = True)
+        response = request_from_api(url, self._user_agent_to_d, as_response_object = True)
     
         return response
     
@@ -400,4 +400,8 @@ class NWSAPy:
         url = 'https://api.weather.gov/alerts/types'
         response_tuple = request_from_api(url, self._user_agent_to_d)
         types = set_data.for_alert_type(response_tuple)
-        return types
\ No newline at end of file
+        return types
+    
+    def get_zones(self, **kwargs):
+        self._check_user_agent()
+        url = 'https://api.weather.gov/zones'
\ No newline at end of file
