@@ -26,4 +26,9 @@ def construct_alert_url(params, is_active_alerts = True):
         
     url_appendage = "&".join(url_appendage)
     url = "?".join([url, url_appendage]).replace(' ', "%20")
-    return url
\ No newline at end of file
+    return url
+
+def construct_zones_url(params):
+    url = 'https://api.weather.gov/zones'
+    
+        
\ No newline at end of file
