@@ -122,6 +122,33 @@ class DataValidationChecker:
     def check_if_valid_marine_region(self, marine_region):
         if not self.dvt.is_valid_region(marine_region):
             raise DataValidationError(marine_region, f'Region: `{marine_region}`')
+    
+    def check_zone_endpoint_kwargs(self, params):
+        url_valid_mapper = {
+            'area' : self.dvt.is_valid_area,
+            'certainty' : self.dvt.is_valid_certainty,
+            'event' : self.dvt.is_valid_product,
+            'region' : self.dvt.is_valid_region,
+            'zone_id' :self.dvt.is_valid_zone,
+        }
+        
+        for key, value in params.items():
+            if key not in url_valid_mapper:
+                continue # TODO: look into other ways to handle this.
+            
+            # equivalent to: is_valid = self.is_valid_xyz(value)
+            
+            # Sometimes, it'll be read in as a list. Other times, it won't.
+            # So, convert it into a list if it's not and then iterate through
+            # it :)
+            if not any([isinstance(value, list), isinstance(value, tuple)]):
+                value = [value]
+            
+            for val in value:    
+                is_valid = url_valid_mapper[key](val)
+            
+                if not is_valid:
+                    raise DataValidationError(value, f"Parameter: `{key}`")
 
 
 class DataValidationTable:
@@ -250,6 +277,10 @@ class DataValidationTable:
             return True
         return False
 
+    @staticmethod
+    def is_valid_zone(zone):
+        pass # this needs to be updated with a list of the zones.
+
 # these functions aren't built into the above class for a few reasons:
 #   1. Maybe the users want to breach outside of the entrypoint and use
 #       these for whatever reason.
@@ -331,9 +362,6 @@ def valid_areas():
 def valid_products():
     """Returns a list of all valid NWS products.
     
-    .. note::
-        If checking for a valid product,
-
     :return: A list of valid NWS products.
     :rtype: list[str]
     """
@@ -389,3 +417,10 @@ def valid_products():
             'Wind Chill Watch', 'Winter Storm Warning', 'Winter Storm Watch', 
             'Winter Weather Advisory'
             ]
+
+def valid_zone_types():
+    """Returns a list of valid zone types, used in ``get_zone()``
+    
+    :return: A list of valid zone types
+    :rtype: list[str]"""
+    return ['land', 'marine', 'forecast', 'fire', 'public', 'coastal', 'offshore', 'county']
\ No newline at end of file
